@@ -24,12 +24,8 @@ VENV = "/opt/stack/bifrost"
 ANSIBLE = os.path.join(VENV, 'bin', 'ansible-playbook')
 COMMON_ENV = {
     'VENV': VENV,
-    'USE_VENV': 'true',
-    'ENABLE_VENV': 'true',
 }
 COMMON_PARAMS = [
-    '-e', 'ansible_python_interpreter=%s/bin/python3' % VENV,
-    '-e', 'enable_venv=true',
     '-e', 'bifrost_venv_dir=%s' % VENV,
 ]
 BASE = os.path.abspath(os.path.join(os.path.dirname(sys.argv[0]), '..'))
@@ -68,14 +64,11 @@ def ansible(playbook, inventory, verbose=False, env=None, extra_vars=None,
 
 
 def env_setup(args):
-    if os.path.exists(VENV):
-        log(VENV, 'exists, skipping environment preparation',
-            only_if=args.debug)
-        return
-
-    log('Installing dependencies and preparing an environment in', VENV)
-    subprocess.check_call(["bash", "scripts/env-setup.sh"],
-                          env=get_env(), cwd=BASE)
+    log('Installing dependencies and preparing an environment in', VENV,
+        only_if=args.debug)
+    env = get_env({'BIFROST_TRACE': str(args.debug).lower(),
+                   'BIFROST_HIDE_PROMPT': 'true'})
+    subprocess.check_call(["bash", "scripts/env-setup.sh"], env=env, cwd=BASE)
 
 
 def get_release(release):
@@ -87,29 +80,29 @@ def get_release(release):
         try:
             gr = configparser.ConfigParser()
             gr.read(os.path.join(BASE, '.gitreview'))
-            release = gr.get('gerrit', 'defaultbranch',
-                             fallback=DEFAULT_BRANCH)
+            release = gr.get('gerrit', 'defaultbranch', fallback=None)
         except (FileNotFoundError, configparser.Error):
-            log('Cannot read .gitreview, falling back to release',
-                DEFAULT_BRANCH)
-            return DEFAULT_BRANCH
+            log('Cannot read .gitreview, falling back to defaults')
+            return None
         else:
-            if release.startswith('bugfix/'):
+            if release and release.startswith('bugfix/'):
                 log('Bugfix branch', release, 'cannot be used as a release, '
-                    'falling back to', DEFAULT_BRANCH)
-                return DEFAULT_BRANCH
+                    'falling back to defaults')
+                return None
             log('Using release', release, 'detected from the checkout')
             return release
 
 
 def cmd_testenv(args):
-    release = get_release(args.release)
-
     env_setup(args)
     log('Creating', args.count, 'test node(s) with', args.memory,
         'MiB RAM and', args.disk, 'GiB of disk')
 
+    release = get_release(args.release)
+
     kwargs = {}
+    if release:
+        kwargs['git_branch'] = release
     if args.storage_pool_path:
         kwargs['test_vm_storage_pool_path'] = os.path.abspath(
             args.storage_pool_path)
@@ -117,7 +110,6 @@ def cmd_testenv(args):
     ansible('test-bifrost-create-vm.yaml',
             inventory='inventory/localhost',
             verbose=args.debug,
-            git_branch=release,
             test_vm_num_nodes=args.count,
             test_vm_memory_size=args.memory,
             test_vm_disk_gib=args.disk,
@@ -134,6 +126,9 @@ def cmd_install(args):
     release = get_release(args.release)
 
     kwargs = {}
+    if release:
+        kwargs.update({'git_branch': release,
+                       'ipa_upstream_release': release.replace('/', '-')})
     if args.dhcp_pool:
         try:
             start, end = args.dhcp_pool.split('-')
@@ -150,14 +145,13 @@ def cmd_install(args):
     ansible('install.yaml',
             inventory='inventory/target',
             verbose=args.debug,
-            git_branch=release,
-            ipa_upstream_release=release.replace('/', '-'),
             create_ipa_image='false',
             create_image_via_dib='false',
             install_dib='true',
             network_interface=args.network_interface,
             enable_keystone=args.enable_keystone,
-            use_public_urls=args.enable_keystone,
+            enable_tls=args.enable_tls,
+            generate_tls=args.enable_tls,
             noauth_mode='false',
             enabled_hardware_types=args.hardware_types,
             cleaning_disk_erase=args.cleaning_disk_erase,
@@ -165,6 +159,7 @@ def cmd_install(args):
             use_cirros=args.testenv,
             use_tinyipa=args.testenv,
             developer_mode=args.develop,
+            enable_prometheus_exporter=args.enable_prometheus_exporter,
             extra_vars=args.extra_vars,
             **kwargs)
     log("Ironic is installed and running, try it yourself:\n",
@@ -185,7 +180,8 @@ def parse_args():
         'testenv', help='Prepare a virtual testing environment')
     testenv.set_defaults(func=cmd_testenv)
     testenv.add_argument('--release', default='master',
-                         help='release branch to use (master, ussuri, etc)')
+                         help='release branch to use (master, ussuri, etc), '
+                              'must match the release of bifrost.')
     testenv.add_argument('--count', type=int, default=2,
                          help='number of nodes to create')
     testenv.add_argument('--memory', type=int, default=3072,
@@ -224,6 +220,8 @@ def parse_args():
                          help='the network interface to use')
     install.add_argument('--enable-keystone', action='store_true',
                          help='enable keystone and use authentication')
+    install.add_argument('--enable-tls', action='store_true',
+                         help='enable self-signed TLS on API endpoints')
     install.add_argument('--hardware-types',
                          # only generic types are enabled in the simple CI
                          default='ipmi,redfish,manual-management',
@@ -233,6 +231,9 @@ def parse_args():
                          action='store_true', default=False,
                          help='enable full disk cleaning between '
                               'deployments (can take a lot of time)')
+    install.add_argument('--enable-prometheus-exporter', action='store_true',
+                         default=False,
+                         help='Enable Ironic Prometheus Exporter')
     install.add_argument('-e', '--extra-vars', action='append',
                          help='additional vars to pass to ansible')
 
